; YOU DO NOT NEED TO MODIFY THIS FILE UNDER ** ANY ** CIRCUMSTANCES!

#include "usgard.h"
#include "spritlib.h"

Width           = 8             ; Width of Sprite
Height          = 8             ; Height of Sprite
Total           = 112           ; Number of Sprites to Draw Per Map
NextYAt         = 128           ; When to zero out the X value and increase
                                ; the Y value.  Typically at 128, the end
                                ; of the screen.

Current         = TEXT_MEM      ; Temporary Variable for Drawing the Map
DrawMapX        = TEXT_MEM+1    ; Temporary Variable for Drawing the Map
DrawMapY        = TEXT_MEM+2    ; Temporary Variable for Drawing the Map
MapPointer      = TEXT_MEM+3    ; 2 byte pointer to &MapA
                                ; Needed for Drawing the Map, must be set
                                ; before DrawMap is called!

.org 0
.db "Darkness Map Test",0
.db SPRITLIB, 0

; This first segment of the program is just a "demo" that calls the MAP
; routine.  Various variables are set here which you must remember to set
; in your program before calling DrawMap

        ld      a, 4
        out     (5), a

        ld      hl, VIDEO_MEM
        LIB_CALL_(SPRITLIB, SET_DEST)   ; set Sprite Destination to Video Mem

        ld      hl, &MapA               ; Tell the routine where our map data
        ld      (MapPointer), hl        ; is located at.  This is so the
                                        ; routine is compatable with multiple
                                        ; maps.

        call    CLEARLCD                ; clear screen, add this to the
                                        ; routine if you need to do it every
                                        ; time.  Pixels are drawn so that
                                        ; they will overwrite the screen
                                        ; completely, so this command is not
                                        ; really necessary.

; The following you need to have before each map is drawn.  You should start
; cutting and pasting here.  You can include a call CLEARLCD if you want.

DrawMap:

        ld      a, Total                ; we need to loop how many times?
        ld      (Current), a            ; save that in map counter
        ld      a, 0                    
        ld      (DrawMapX), a           ; we currently are on 0, 0
        ld      (DrawMapY), a

DrawMapLoop:

; the following loads the sprite coordinates into HL so it can be displayed

        ld      hl, (MapPointer)        ; load Map location in memory
        ld      a, (Current)            ; load block number we're on

        ld      d, a                    ; |
        ld      a, Total                ; |   Total Loops - (block number)
        sub     d                       ; | 

        ld      d, 0                    ; | Add (Loops - (block number)) to
        ld      e, a                    ; | hl, which points to the "map".
        add     hl, de                  ; | This gets the position in the
                                        ; | map we need.

        ld      a, (hl)                 ; get what the map says the value is

; now that we have what the block number is (0, 1, 2, etc), we need to find
; where, in memory, the sprite that cooresponds to that number is located at
; in memory.  This is done by a Sprite Location table.  This version supports
; up to 256 sprites, numbered 0 - 255.  The addresses of the sprites are
; located near the end of the program, in SpriteTable.

        ld      hl, &SpriteTable        ; load the raw location of table
        add     a, a                    ; double a, since each sprite pointer
                                        ; is two bytes
        ld      d, 0
        ld      e, a                   
        add     hl, de          ; get from the sprite table where exactly

; hl now points to a pointer in SpriteTable.  We need to load the value now.

        call    LD_HL_MHL

; equivalant of ld      hl, (hl) which is not legal.  This loads the location
; of the sprite into hl (ie, loads "SpriteA" into memory).

        ld      de, (PROGRAM_ADDR)      ; add PROGRAM_ADDR, relocation is not
                                        ; going to work here!
        add     hl, de

; the following code determines at what screen position to draw the sprite
; and stores it into BC.  It just loads these numbers out of DrawMapY and
; DrawMapX

        ld      a, (DrawMapY)
        ld      c, a
        ld      a, (DrawMapX)
        ld      b, a

; now we actually draw the sprite

        LIB_CALL_(SPRITLIB,PUTSPRIT)    ; draw the sprite

; update our screen position counters and things of the sort

        ld      a, (DrawMapX)

        add     a, Width
        cp      NextYAt                 ; if this is the end of the X row
        call    z, &UpdateMapY          ;  then increase Y pointer
                                        ; UpdateMapY will put a "0" into a
        ld      (DrawMapX), a           ; increase X pointer either way
                                        ; (must happen after UpdateMapY is
                                        ;  called)

        ld      a, (Current)
        ld      b, a
        dec     a
        ld      (Current), a            ; decrease block number

        djnz    DrawMapLoop             ; loop until block number is 0

        call    OTH_PAUSE               ; pause

        ret                             ; end the program

UpdateMapY:
        ld      a, (DrawMapY)
        add     a, Height               ; increase the Y pointer by height
                                        ; of each sprite
        ld      (DrawMapY), a
        ld      a, 0                    ; set the X pointer to 0 (it's saved
                                        ; back into a variable when this
                                        ; function RETs).
        ret

; Following in SPRITES.ASM:
; Locations of sprites in memory.  Start with what you want sprite "0" to be
; and go until you don't need anymore.
; The actual sprites.  I use PutSprite format.

#include "sprites.asm"

; Map data.

MapA:
#include "mymap.asm"

.end
